pub struct NavStatus {
pub status: TaskStatus,
pub ty: TaskType,
pub target_id: PointId,
pub target_point: [f64; 3],
pub finished_path: Vec<PointId>,
pub unfinished_path: Vec<PointId>,
pub move_status_info: String,
pub code: Option<StatusCode>,
pub create_on: Option<String>,
pub message: String,
}Fields
status: TaskStatusty: TaskTypetarget_id: PointIdtarget_point: [f64; 3]Target point coordinates (x, y, angle)
finished_path: Vec<PointId>Stations already passed on the current navigation path, an array of stations, this field is only valid when task_type is 3. All intermediate points already passed will be listed here
unfinished_path: Vec<PointId>Stations on the current navigation path that have not yet been passed, represented as an array of stations, are only valid when task_type is 3. All intermediate points that have not yet been passed will be listed here.
move_status_info: StringNavigation Task Additional Information
code: Option<StatusCode>API Error Code
create_on: Option<String>API Upload Timestamp
message: StringError Message