pub struct TaskPackage {
pub closest_target: PointId,
pub source_name: TaskId,
pub target_name: TaskId,
pub percentage: f64,
pub distance: Option<f64>,
pub tasks: Vec<TaskStatusItem>,
pub info: String,
pub code: Option<StatusCode>,
pub message: String,
pub create_on: Option<String>,
}Fields
closest_target: PointIdThe station closest to the robot within a certain linear distance (this distance is a
source_name: TaskIdThe “source_id” in the navigation task currently being executed by the robot
target_name: TaskIdThe “id” of the navigation task currently being executed by the robot
percentage: f64In the navigation task currently being executed by the robot, for the corresponding path, the proportion of the part that the robot has completed to the entire path
distance: Option<f64>Projection distance of the robot to the “path corresponding to the currently executing navigation task
tasks: Vec<TaskStatusItem>info: StringDuring the navigation process, some prompts from the robot to the user can be output to the front end. This field does not participate in actual logical judgment
code: Option<StatusCode>message: Stringcreate_on: Option<String>Trait Implementations
Sourceimpl Clone for TaskPackage
impl Clone for TaskPackage
Sourcefn clone(&self) -> TaskPackage
fn clone(&self) -> TaskPackage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskPackage
impl Debug for TaskPackage
Sourceimpl<'de> Deserialize<'de> for TaskPackage
impl<'de> Deserialize<'de> for TaskPackage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more