pub struct GetTaskStatus {
pub task_ids: Vec<String>,
}Fields
task_ids: Vec<String>Specify the task_id of the task to be queried in the array. If the array is empty, the response will also be empty; If this field is omitted, the status of the most recently completed task and the status of all incomplete tasks of the robot will be returned.
Implementations
Sourceimpl GetTaskStatus
impl GetTaskStatus
pub fn into_request(self) -> TaskStatusRequest