pub struct MoveToTarget {Show 16 fields
pub target: PointId,
pub start: PointId,
pub task_id: Option<TaskId>,
pub method: Option<MoveMethod>,
pub spin: Option<bool>,
pub delay: u64,
pub start_rot_dir: Option<i8>,
pub end_rot_dir: Option<i8>,
pub reach_dist: Option<f64>,
pub reach_angle: Option<f64>,
pub angle: Option<f64>,
pub max_speed: Option<f64>,
pub max_wspeed: Option<f64>,
pub max_acc: Option<f64>,
pub max_wacc: Option<f64>,
pub jack_operation: Option<JackOperation>,
}Fields
target: PointIdTarget Station Name When the robot executes an operation in place, its fixed value is “SELF_POSITION”
start: PointIdStarting Station Name When the starting position is not at a station but the current position of the robot, its value is fixed as “SELF_POSITION”
task_id: Option<TaskId>Unique Task ID Can be ommitted when only a single MoveToTarget is used But required when used in a list of MoveToTargets
method: Option<MoveMethod>When ommitted, the mode configured on the path will be used
spin: Option<bool>Follow-up or not
delay: u64Delays the time to end the navigation state, with the unit in ms, defaulting to 0
start_rot_dir: Option<i8>Starting in-place rotation direction -1: Clockwise rotation 0: Rotate towards the nearest direction 1: Counterclockwise rotation
end_rot_dir: Option<i8>Rotation direction at the point -1: Clockwise rotation 0: Rotate towards the nearest direction 1: Counterclockwise rotation
reach_dist: Option<f64>Position Accuracy (m)
reach_angle: Option<f64>Angle Accuracy (rad)
angle: Option<f64>max_speed: Option<f64>max_wspeed: Option<f64>max_acc: Option<f64>max_wacc: Option<f64>jack_operation: Option<JackOperation>Implementations
Sourceimpl MoveToTarget
impl MoveToTarget
pub fn new<T: Into<String>>(target: T) -> Self
pub fn with_task_id(self, value: TaskId) -> Self
pub fn with_start(self, value: PointId) -> Self
pub fn with_method(self, value: MoveMethod) -> Self
pub fn with_operation(self, value: JackOperation) -> Self
Sourceimpl MoveToTarget
impl MoveToTarget
pub fn into_request(self) -> MoveToTargetRequest